# pydantic-weather-agent
A simple demonstration of pydantic AI Agent framework to perform a weather search task

> [!IMPORTANT]  
> You will need to create a .env file and populate it with the following environment variables:
- WEATHER_API_KEY # create a free API key at https://www.tomorrow.io/weather-api/
- GEOCODING_API_KEY # create a free API key at https://geocode.maps.co/
- OPENAI_API_KEY